diff --git a/typo3/sysext/fluid/Classes/ViewHelpers/IfViewHelper.php b/typo3/sysext/fluid/Classes/ViewHelpers/IfViewHelper.php
index 2db8da491cc4fa57086e40adb4327a6f784892b7..24ac60561ea198f3ae24d4f9dbfdf65a785660cb 100644
--- a/typo3/sysext/fluid/Classes/ViewHelpers/IfViewHelper.php
+++ b/typo3/sysext/fluid/Classes/ViewHelpers/IfViewHelper.php
@@ -84,13 +84,10 @@ namespace TYPO3\CMS\Fluid\ViewHelpers;
 class IfViewHelper extends \TYPO3\CMS\Fluid\Core\ViewHelper\AbstractConditionViewHelper {
 
 	/**
-	 * renders <f:then> child if $condition is true, otherwise renders <f:else> child.
-	 *
-	 * @param bool $condition View helper condition
-	 * @return string the rendered string
-	 * @api
+	 * @return void
 	 */
-	public function render($condition) {
-		return parent::render();
+	public function initializeArguments() {
+		$this->registerArgument('condition', 'boolean', 'Condition to be evaluated.');
 	}
+
 }
diff --git a/typo3/sysext/fluid/Classes/ViewHelpers/Be/Security/IfHasRoleViewHelper.php b/typo3/sysext/fluid/Classes/ViewHelpers/Be/Security/IfHasRoleViewHelper.php
index 4f3aefdb6c75b4752535e2a31853d1b91e4054b8..fcf99b38b6394ea4aed105298569d2fc25c22fc3 100644
--- a/typo3/sysext/fluid/Classes/ViewHelpers/Be/Security/IfHasRoleViewHelper.php
+++ b/typo3/sysext/fluid/Classes/ViewHelpers/Be/Security/IfHasRoleViewHelper.php
@@ -63,15 +63,14 @@ namespace TYPO3\CMS\Fluid\ViewHelpers\Be\Security;
 class IfHasRoleViewHelper extends \TYPO3\CMS\Fluid\Core\ViewHelper\AbstractConditionViewHelper {
 
 	/**
 	 * renders <f:then> child if the current logged in BE user belongs to the specified role (aka usergroup)
 	 * otherwise renders <f:else> child.
 	 *
-	 * @param string $role The usergroup (either the usergroup uid or its title)
-	 * @return string the rendered string
-	 * @api
+	 * @return void
 	 */
-	public function render($role) {
-		return parent::render();
+	public function initializeArguments() {
+		$this->registerArgument('role', 'string', 'The usergroup (either the usergroup uid or its title).');
 	}
 
 	/**
@@ -63,15 +63,14 @@ namespace TYPO3\CMS\Fluid\ViewHelpers\Be\Security;
 
 	/**
-	 * renders <f:then> child if the current logged in BE user belongs to the specified role (aka usergroup)
+	 * Initializes the "role" argument.
+	 * Renders <f:then> child if the current logged in BE user belongs to the specified role (aka usergroup)
 	 * otherwise renders <f:else> child.
 	 *
diff --git a/typo3/sysext/fluid/Classes/ViewHelpers/Security/IfHasRoleViewHelper.php b/typo3/sysext/fluid/Classes/ViewHelpers/Security/IfHasRoleViewHelper.php
index 818d9630f3b6238bacedd6bc537435a86d7c28ac..02fa90e9b2060657c3e4f53fbccd5dd66f4647aa 100644
--- a/typo3/sysext/fluid/Classes/ViewHelpers/Security/IfHasRoleViewHelper.php
+++ b/typo3/sysext/fluid/Classes/ViewHelpers/Security/IfHasRoleViewHelper.php
@@ -63,15 +63,14 @@ namespace TYPO3\CMS\Fluid\ViewHelpers\Security;
 class IfHasRoleViewHelper extends \TYPO3\CMS\Fluid\Core\ViewHelper\AbstractConditionViewHelper {
 
 	/**
 	 * renders <f:then> child if the current logged in FE user belongs to the specified role (aka usergroup)
 	 * otherwise renders <f:else> child.
 	 *
-	 * @param string $role The usergroup (either the usergroup uid or its title)
-	 * @return string the rendered string
-	 * @api
+	 * @return void
 	 */
-	public function render($role) {
-		return parent::render();
+	public function initializeArguments() {
+		$this->registerArgument('role', 'string', 'The usergroup (either the usergroup uid or its title).');
 	}
 
 	/**
@@ -63,15 +63,14 @@ namespace TYPO3\CMS\Fluid\ViewHelpers\Security;
 
 	/**
-	 * renders <f:then> child if the current logged in FE user belongs to the specified role (aka usergroup)
+	 * Initializes the "role" argument.
+	 * Renders <f:then> child if the current logged in FE user belongs to the specified role (aka usergroup)
 	 * otherwise renders <f:else> child.
 	 *